@@ -1,13 +1,15 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "controlsocket.h"
 #include "directorycache.h"
 #include "engineprivate.h"
-#include "local_path.h"
 #include "lookup.h"
 #include "logging_private.h"
 #include "proxy.h"
 #include "servercapabilities.h"
-#include "sizeformatting_base.h"
+
+#include "../include/local_path.h"
+#include "../include/engine_options.h"
+#include "../include/sizeformatting_base.h"
 
 #include <libfilezilla/event_loop.hpp>
 #include <libfilezilla/iputils.hpp>
@@ -389,37 +391,37 @@ int CControlSocket::CheckOverwriteFile()
 		}
 	}
 
-	CFileExistsNotification *pNotification = new CFileExistsNotification;
+	auto notification = std::make_unique<CFileExistsNotification>();
 
-	pNotification->download = data.download_;
-	pNotification->localFile = data.localFile_;
-	pNotification->remoteFile = data.remoteFile_;
-	pNotification->remotePath = data.remotePath_;
-	pNotification->localSize = data.localFileSize_;
-	pNotification->remoteSize = data.remoteFileSize_;
-	pNotification->remoteTime = data.fileTime_;
-	pNotification->ascii = !data.transferSettings_.binary;
+	notification->download = data.download_;
+	notification->localFile = data.localFile_;
+	notification->remoteFile = data.remoteFile_;
+	notification->remotePath = data.remotePath_;
+	notification->localSize = data.localFileSize_;
+	notification->remoteSize = data.remoteFileSize_;
+	notification->remoteTime = data.fileTime_;
+	notification->ascii = !data.transferSettings_.binary;
 
-	if (data.download_ && pNotification->localSize >= 0) {
-		pNotification->canResume = true;
+	if (data.download_ && notification->localSize >= 0) {
+		notification->canResume = true;
 	}
-	else if (!data.download_ && pNotification->remoteSize >= 0) {
-		pNotification->canResume = true;
+	else if (!data.download_ && notification->remoteSize >= 0) {
+		notification->canResume = true;
 	}
 	else {
-		pNotification->canResume = false;
+		notification->canResume = false;
 	}
 
-	pNotification->localTime = fz::local_filesys::get_modification_time(fz::to_native(data.localFile_));
+	notification->localTime = fz::local_filesys::get_modification_time(fz::to_native(data.localFile_));
 
 	if (found) {
-		if (pNotification->remoteTime.empty() && entry.has_date()) {
-			pNotification->remoteTime = entry.time;
+		if (notification->remoteTime.empty() && entry.has_date()) {
+			notification->remoteTime = entry.time;
 			data.fileTime_ = entry.time;
 		}
 	}
 
-	SendAsyncRequest(pNotification);
+	SendAsyncRequest(std::move(notification));
 
 	return FZ_REPLY_WOULDBLOCK;
 }
@@ -512,7 +514,7 @@ void CControlSocket::OnTimer(fz::timer_id)
 {
 	m_timer = 0; // It's a one-shot timer, no need to stop it
 
-	int const timeout = engine_.GetOptions().GetOptionVal(OPTION_TIMEOUT);
+	int const timeout = engine_.GetOptions().get_int(OPTION_TIMEOUT);
 	if (timeout > 0) {
 		fz::duration elapsed = fz::monotonic_clock::now() - m_lastActivity;
 
@@ -545,7 +547,7 @@ void CControlSocket::SetWait(bool wait)
 
 		m_lastActivity = fz::monotonic_clock::now();
 
-		int timeout = engine_.GetOptions().GetOptionVal(OPTION_TIMEOUT);
+		int timeout = engine_.GetOptions().get_int(OPTION_TIMEOUT);
 		if (!timeout) {
 			return;
 		}
@@ -655,29 +657,29 @@ void CControlSocket::InvalidateCurrentWorkingDir(const CServerPath& path)
 	}
 }
 
-fz::duration CControlSocket::GetTimezoneOffset() const
+fz::duration CControlSocket::GetInferredTimezoneOffset() const
 {
 	fz::duration ret;
 	if (currentServer_) {
 		int seconds = 0;
-		if (CServerCapabilities::GetCapability(currentServer_, timezone_offset, &seconds) == yes) {
+		if (CServerCapabilities::GetCapability(currentServer_, inferred_timezone_offset, &seconds) == yes) {
 			ret = fz::duration::from_seconds(seconds);
 		}
 	}
 	return ret;
 }
 
-void CControlSocket::SendAsyncRequest(CAsyncRequestNotification* pNotification)
+void CControlSocket::SendAsyncRequest(std::unique_ptr<CAsyncRequestNotification> && notification)
 {
-	assert(pNotification);
-	assert(!operations_.empty());
-
-	pNotification->requestNumber = engine_.GetNextAsyncRequestNumber();
+	if (!notification || operations_.empty()) {
+		return;
+	}
+	notification->requestNumber = engine_.GetNextAsyncRequestNumber();
 
 	if (!operations_.empty()) {
 		operations_.back()->waitForAsyncRequest = true;
 	}
-	engine_.AddNotification(pNotification);
+	engine_.AddNotification(std::move(notification));
 }
 
 // ------------------
@@ -858,16 +860,16 @@ int CRealControlSocket::DoConnect(std::wstring const& host, unsigned int port)
 	ratelimit_layer_ = std::make_unique<fz::rate_limited_layer>(this, *socket_, &engine_.GetRateLimiter());
 	active_layer_ = ratelimit_layer_.get();
 
-	const int proxy_type = engine_.GetOptions().GetOptionVal(OPTION_PROXY_TYPE);
+	const int proxy_type = engine_.GetOptions().get_int(OPTION_PROXY_TYPE);
 	if (proxy_type > static_cast<int>(ProxyType::NONE) && proxy_type < static_cast<int>(ProxyType::count) && !currentServer_.GetBypassProxy()) {
 		log(logmsg::status, _("Connecting to %s through %s proxy"), currentServer_.Format(ServerFormat::with_optional_port), CProxySocket::Name(static_cast<ProxyType>(proxy_type)));
 
-		fz::native_string proxy_host = fz::to_native(engine_.GetOptions().GetOption(OPTION_PROXY_HOST));
+		fz::native_string proxy_host = fz::to_native(engine_.GetOptions().get_string(OPTION_PROXY_HOST));
 
 		proxy_layer_ = std::make_unique<CProxySocket>(this, *active_layer_, this, static_cast<ProxyType>(proxy_type),
-			proxy_host, engine_.GetOptions().GetOptionVal(OPTION_PROXY_PORT),
-			engine_.GetOptions().GetOption(OPTION_PROXY_USER),
-			engine_.GetOptions().GetOption(OPTION_PROXY_PASS));
+			proxy_host, engine_.GetOptions().get_int(OPTION_PROXY_PORT),
+			engine_.GetOptions().get_string(OPTION_PROXY_USER),
+			engine_.GetOptions().get_string(OPTION_PROXY_PASS));
 		active_layer_ = proxy_layer_.get();
 
 		if (fz::get_address_type(proxy_host) == fz::address_type::unknown) {
@@ -1084,14 +1086,15 @@ void CControlSocket::CreateLocalDir(std::wstring const& local_file)
 		return;
 	}
 
-	CLocalPath last_successful;
-	local_path.Create(&last_successful);
+	fz::native_string last_created;
+	fz::mkdir(fz::to_native(local_path.GetPath()), true, false, &last_created);
 
-	if (!last_successful.empty()) {
+	if (!last_created.empty()) {
 		// Send out notification
-		CLocalDirCreatedNotification *n = new CLocalDirCreatedNotification;
-		n->dir = last_successful;
-		engine_.AddNotification(n);
+		auto n = std::make_unique<CLocalDirCreatedNotification>();
+		if (n->dir.SetPath(fz::to_wstring(last_created))) {
+			engine_.AddNotification(std::move(n));
+		}
 	}
 }
 
@@ -1159,7 +1162,7 @@ void CControlSocket::SendDirectoryListingNotification(CServerPath const& path, b
 		return;
 	}
 
-	engine_.AddNotification(new CDirectoryListingNotification(path, operations_.size() == 1 && operations_.back()->opId == Command::list, failed));
+	engine_.AddNotification(std::make_unique<CDirectoryListingNotification>(path, operations_.size() == 1 && operations_.back()->opId == Command::list, failed));
 }
 
 void CControlSocket::CallSetAsyncRequestReply(CAsyncRequestNotification *pNotification)
@@ -1208,7 +1211,7 @@ int64_t CalculateNextChunkSize(int64_t remaining, int64_t lastChunkSize, fz::dur
 
 	if (multiple) {
 		// Round up
-		int modulus = newChunkSize % multiple;
+		auto modulus = newChunkSize % multiple;
 		if (modulus) {
 			newChunkSize += multiple - modulus;
 		}
