@@ -1,17 +1,16 @@
 #ifndef FILEZILLA_ENGINE_CONTROLSOCKET_HEADER
 #define FILEZILLA_ENGINE_CONTROLSOCKET_HEADER
 
+#include "../include/directorylisting.h"
+#include "../include/server.h"
+#include "../include/serverpath.h"
+
 #include "logging_private.h"
+#include "oplock_manager.h"
 
 #include <libfilezilla/buffer.hpp>
 #include <libfilezilla/socket.hpp>
 
-#include <directorylisting.h>
-
-#include "oplock_manager.h"
-#include "server.h"
-#include "serverpath.h"
-
 class COpData
 {
 public:
@@ -225,7 +224,7 @@ public:
 
 	Command GetCurrentCommandId() const;
 
-	void SendAsyncRequest(CAsyncRequestNotification* pNotification);
+	void SendAsyncRequest(std::unique_ptr<CAsyncRequestNotification> && notification);
 	void CallSetAsyncRequestReply(CAsyncRequestNotification *pNotification);
 	bool SetFileExistsAction(CFileExistsNotification *pFileExistsNotification);
 
@@ -281,7 +280,7 @@ protected:
 	virtual bool SetAsyncRequestReply(CAsyncRequestNotification *pNotification) = 0;
 	void SendDirectoryListingNotification(CServerPath const& path, bool failed);
 
-	fz::duration GetTimezoneOffset() const;
+	fz::duration GetInferredTimezoneOffset() const;
 
 	virtual int DoClose(int nErrorCode = FZ_REPLY_DISCONNECTED | FZ_REPLY_ERROR);
 
