@@ -14,10 +14,9 @@ enum connectStates
 class CSftpConnectOpData final : public COpData, public CSftpOpData
 {
 public:
-	CSftpConnectOpData(CSftpControlSocket & controlSocket, Credentials const& credentials)
-		: COpData(Command::connect, L"CSftpDeleteOpData")
+	CSftpConnectOpData(CSftpControlSocket & controlSocket)
+		: COpData(Command::connect, L"CSftpConnectOpData")
 		, CSftpOpData(controlSocket)
-		, credentials_(credentials)
 		, keyfile_(keyfiles_.cend())
 	{}
 
@@ -29,8 +28,6 @@ public:
 	CInteractiveLoginNotification::type lastChallengeType{ CInteractiveLoginNotification::interactive };
 	bool criticalFailure{};
 
-	Credentials credentials_;
-
 	std::vector<std::wstring> keyfiles_;
 	std::vector<std::wstring>::const_iterator keyfile_;
 };
