@@ -1,24 +1,27 @@
-#include <filezilla.h>
+#include "../filezilla.h"
 
 #include "chmod.h"
 #include "connect.h"
 #include "cwd.h"
 #include "delete.h"
-#include "../directorycache.h"
-#include "directorylistingparser.h"
-#include "engineprivate.h"
 #include "event.h"
 #include "filetransfer.h"
 #include "list.h"
 #include "input_thread.h"
 #include "mkd.h"
-#include "pathcache.h"
-#include "proxy.h"
 #include "rename.h"
 #include "rmd.h"
-#include "servercapabilities.h"
 #include "sftpcontrolsocket.h"
 
+#include "../directorycache.h"
+#include "../directorylistingparser.h"
+#include "../engineprivate.h"
+#include "../pathcache.h"
+#include "../proxy.h"
+#include "../servercapabilities.h"
+
+#include "../../include/engine_options.h"
+
 #include <libfilezilla/event_loop.hpp>
 #include <libfilezilla/process.hpp>
 
@@ -137,7 +140,7 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 				DoClose(FZ_REPLY_INTERNALERROR);
 				break;
 			}
-			SendAsyncRequest(new CHostKeyNotification(message.text[0], port, m_sftpEncryptionDetails, message.type == sftpEvent::AskHostkeyChanged));
+			SendAsyncRequest(std::make_unique<CHostKeyNotification>(message.text[0], port, m_sftpEncryptionDetails, message.type == sftpEvent::AskHostkeyChanged));
 		}
 		break;
 	case sftpEvent::AskHostkeyBetteralg:
@@ -170,12 +173,12 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 				if (message.text[0] != L"Password:") {
 					challenge += message.text[0];
 				}
-				CInteractiveLoginNotification *pNotification = new CInteractiveLoginNotification(t, challenge, data.lastChallenge == challengeIdentifier);
-				pNotification->server = currentServer_;
-				pNotification->handle_ = handle_;
-				pNotification->credentials = credentials_;
+				auto notification = std::make_unique<CInteractiveLoginNotification>(t, challenge, data.lastChallenge == challengeIdentifier);
+				notification->server = currentServer_;
+				notification->handle_ = handle_;
+				notification->credentials = credentials_;
 
-				SendAsyncRequest(pNotification);
+				SendAsyncRequest(std::move(notification));
 			}
 			else {
 				if (!data.lastChallenge.empty() && data.lastChallengeType != CInteractiveLoginNotification::keyfile) {
@@ -578,13 +581,13 @@ void CSftpControlSocket::OnQuotaRequest(fz::direction::type const d)
 	}
 	else if (bytes > 0) {
 		int b;
-		if (bytes > std::numeric_limits<int>::max()) {
+		if (bytes > static_cast<size_t>(std::numeric_limits<int>::max())) {
 			b = std::numeric_limits<int>::max();
 		}
 		else {
 			b = static_cast<int>(bytes);
 		}
-		AddToStream(fz::sprintf("-%d%d,%d\n", d, b, engine_.GetOptions().GetOptionVal(OPTION_SPEEDLIMIT_INBOUND + static_cast<int>(d))));
+		AddToStream(fz::sprintf("-%d%d,%d\n", d, b, engine_.GetOptions().get_int(d ? OPTION_SPEEDLIMIT_OUTBOUND : OPTION_SPEEDLIMIT_INBOUND)));
 		consume(d, static_cast<size_t>(bytes));
 	}
 }
