@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "buildinfo.h"
 
 #include <libfilezilla/format.hpp>
