@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "dialogex.h"
 #include "msgbox.h"
 #include "xrc_helper.h"
@@ -20,6 +20,8 @@ std::vector<wxDialogEx*> wxDialogEx::shown_dialogs_;
 std::vector<void*> wxDialogEx::shown_dialogs_creation_events_;
 
 static int const pasteId = wxNewId();
+static int const copyId = wxNewId();
+static int const cutId = wxNewId();
 static int const selectAllId = wxNewId();
 
 extern wxTextEntry* GetSpecialTextEntry(wxWindow*, wxChar);
@@ -35,6 +37,14 @@ bool wxDialogEx::ProcessEvent(wxEvent& event)
 		e->Paste();
 		return true;
 	}
+	else if (e && event.GetId() == copyId) {
+		e->Copy();
+		return true;
+	}
+	else if (e && event.GetId() == cutId) {
+		e->Cut();
+		return true;
+	}
 	else if (e && event.GetId() == selectAllId) {
 		e->SelectAll();
 		return true;
@@ -358,6 +368,8 @@ std::wstring LabelEscape(std::wstring const& label)
 void FixPasswordPaste(std::vector<wxAcceleratorEntry> & entries)
 {
 	entries.emplace_back(wxACCEL_CMD, 'V', pasteId);
+	entries.emplace_back(wxACCEL_CMD, 'C', copyId);
+	entries.emplace_back(wxACCEL_CMD, 'X', cutId);
 	entries.emplace_back(wxACCEL_CMD, 'A', selectAllId);
 }
 #endif
