@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "quickconnectbar.h"
 #include "recentserverlist.h"
 #include "commandqueue.h"
@@ -26,7 +26,7 @@ bool CQuickconnectBar::Create(CMainFrame* pParent)
 {
 	m_pMainFrame = pParent;
 
-	if (!wxPanel::Create(pParent, XRCID("ID_QUICKCONNECT"))) {
+	if (!wxPanel::Create(pParent, -1)) {
 		return false;
 	}
 
@@ -97,6 +97,8 @@ bool CQuickconnectBar::Create(CMainFrame* pParent)
 			event.Skip();
 		}
 	});
+
+	GetSizer()->Fit(this);
 	return true;
 }
 
@@ -178,7 +180,7 @@ void CQuickconnectBar::OnQuickconnect(wxCommandEvent& event)
 		return;
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) && site.credentials.logonType_ == LogonType::normal) {
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) && site.credentials.logonType_ == LogonType::normal) {
 		site.SetLogonType(LogonType::ask);
 		CLoginManager::Get().RememberPassword(site);
 	}
@@ -196,7 +198,7 @@ void CQuickconnectBar::OnQuickconnectDropdown(wxCommandEvent& event)
 	wxMenu* pMenu = new wxMenu;
 
 	// We have to start with id 1 since menu items with id 0 don't work under OS X
-	if (COptions::Get()->GetOptionVal(OPTION_FTP_PROXY_TYPE)) {
+	if (COptions::Get()->get_int(OPTION_FTP_PROXY_TYPE)) {
 		pMenu->Append(1, _("Connect bypassing proxy settings"));
 	}
 	pMenu->Append(2, _("Clear quickconnect bar"));
