@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 
 #define FILELISTCTRL_INCLUDE_TEMPLATE_DEFINITION
 
@@ -642,7 +642,7 @@ bool CSearchDialog::Load()
 	auto main = new wxBoxSizer(wxVERTICAL);
 	SetSizer(main);
 
-	auto optionsSizer = new wxFlexGridSizer(3, 7, 5);
+	auto optionsSizer = lay.createFlex(3);
 	optionsSizer->AddGrowableCol(1);
 	main->Add(optionsSizer, 0, wxALL | wxGROW, lay.border);
 
@@ -740,14 +740,14 @@ bool CSearchDialog::Load()
 
 	SetCtrlState();
 
-	const int mode = COptions::Get()->GetOptionVal(OPTION_COMPARISONMODE);
+	const int mode = COptions::Get()->get_int(OPTION_COMPARISONMODE);
 	if (mode == 0) {
 		xrc_call(*this, "ID_COMPARE_SIZE", &wxRadioButton::SetValue, true);
 	}
 	else {
 		xrc_call(*this, "ID_COMPARE_DATE", &wxRadioButton::SetValue, true);
 	}
-	xrc_call(*this, "ID_COMPARE_HIDEIDENTICAL", &wxCheckBox::SetValue, COptions::Get()->GetOptionVal(OPTION_COMPARE_HIDEIDENTICAL) != 0);
+	xrc_call(*this, "ID_COMPARE_HIDEIDENTICAL", &wxCheckBox::SetValue, COptions::Get()->get_int(OPTION_COMPARE_HIDEIDENTICAL) != 0);
 
 	LoadConditions();
 	EditFilter(m_search_filter);
@@ -1168,8 +1168,6 @@ void CSearchDialog::Stop()
 
 void CSearchDialog::SetCtrlState()
 {
-	bool const localSearch = xrc_call(*this, "ID_LOCAL_SEARCH", &wxRadioButton::GetValue);
-
 	xrc_call(*this, "ID_START", &wxButton::Enable, !searching_);
 	xrc_call(*this, "ID_STOP", &wxButton::Enable, searching_);
 	xrc_call(*this, "ID_LOCAL_SEARCH", &wxRadioButton::Enable, !searching_);
@@ -1185,10 +1183,10 @@ void CSearchDialog::SetCtrlState()
 	xrc_call(*this, "ID_LOCAL_RESULTS_LABEL", &wxStaticText::Show, comparison);
 	xrc_call(*this, "ID_REMOTE_RESULTS_LABEL", &wxStaticText::Show, comparison);
 	if (comparison) {
-		xrc_call(*this, "ID_PATH_LABEL", &wxStaticText::SetLabel, _T("Local &directory:"));
+		xrc_call(*this, "ID_PATH_LABEL", &wxStaticText::SetLabel, _("Local &directory:"));
 	}
 	else {
-		xrc_call(*this, "ID_PATH_LABEL", &wxStaticText::SetLabel, _T("Search &directory:"));
+		xrc_call(*this, "ID_PATH_LABEL", &wxStaticText::SetLabel, _("Search &directory:"));
 	}
 	xrc_call(*this, "ID_COMPARE_LABEL", &wxStaticText::Show, comparison);
 	xrc_call(*this, "ID_COMPARE_SIZE", &wxRadioButton::Show, comparison);
@@ -1265,7 +1263,7 @@ public:
 	{
 		download_ = download;
 
-		if (!Load(parent, download ? _T("ID_SEARCH_DOWNLOAD") : _T("ID_SEARCH_UPLOAD"))) {
+		if (!Load(parent, download ? L"ID_SEARCH_DOWNLOAD" : L"ID_SEARCH_UPLOAD")) {
 			return false;
 		}
 
@@ -1481,7 +1479,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 
 		CServerPath remote_path = entry.path;
 		std::wstring localName = CQueueView::ReplaceInvalidCharacters(entry.name);
-		if (!entry.is_dir() && remote_path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
+		if (!entry.is_dir() && remote_path.GetType() == VMS && COptions::Get()->get_int(OPTION_STRIP_VMS_REVISION))
 			localName = StripVMSRevision(localName);
 
 		m_pQueue->QueueFile(!start, true,
@@ -1765,7 +1763,7 @@ void CSearchDialog::LoadConditions()
 {
 	CInterProcessMutex mutex(MUTEX_SEARCHCONDITIONS);
 
-	CXmlFile file(wxGetApp().GetSettingsFile(_T("search")));
+	CXmlFile file(wxGetApp().GetSettingsFile(L"search"));
 	auto document = file.Load(true);
 	if (!document) {
 		wxMessageBoxEx(file.GetError(), _("Error loading xml file"), wxICON_ERROR);
@@ -1799,7 +1797,7 @@ void CSearchDialog::SaveConditions()
 {
 	CInterProcessMutex mutex(MUTEX_SEARCHCONDITIONS);
 
-	CXmlFile file(wxGetApp().GetSettingsFile(_T("search")));
+	CXmlFile file(wxGetApp().GetSettingsFile(L"search"));
 	auto document = file.Load(true);
 	if (!document) {
 		wxMessageBoxEx(file.GetError(), _("Error loading xml file"), wxICON_ERROR);
