@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "../filezilla.h"
 #include "../Options.h"
 #include "settingsdialog.h"
 #include "optionspage.h"
@@ -8,18 +8,18 @@ bool COptionsPageFileExists::LoadPage()
 {
 	bool failure = false;
 
-	int dlAction = m_pOptions->GetOptionVal(OPTION_FILEEXISTS_DOWNLOAD);
+	int dlAction = m_pOptions->get_int(OPTION_FILEEXISTS_DOWNLOAD);
 	if (dlAction < 0 || dlAction >= CFileExistsNotification::ACTION_COUNT)
 		dlAction = 0;
 	SetChoice(XRCID("ID_DOWNLOAD_ACTION"), dlAction, failure);
 
-	int ulAction = m_pOptions->GetOptionVal(OPTION_FILEEXISTS_UPLOAD);
+	int ulAction = m_pOptions->get_int(OPTION_FILEEXISTS_UPLOAD);
 	if (ulAction < 0 || ulAction >= CFileExistsNotification::ACTION_COUNT)
 		ulAction = 0;
 	SetChoice(XRCID("ID_UPLOAD_ACTION"), ulAction, failure);
 
-	SetCheck(XRCID("ID_ASCIIRESUME"), m_pOptions->GetOptionVal(OPTION_ASCIIRESUME) ? true : false, failure);
-	
+	SetCheck(XRCID("ID_ASCIIRESUME"), m_pOptions->get_int(OPTION_ASCIIRESUME) ? true : false, failure);
+
 	return !failure;
 }
 
@@ -28,14 +28,14 @@ bool COptionsPageFileExists::SavePage()
 	int dlAction = GetChoice(XRCID("ID_DOWNLOAD_ACTION"));
 	if (dlAction < 0 || dlAction >= CFileExistsNotification::ACTION_COUNT)
 		dlAction = 0;
-	m_pOptions->SetOption(OPTION_FILEEXISTS_DOWNLOAD, dlAction);
+	m_pOptions->set(OPTION_FILEEXISTS_DOWNLOAD, dlAction);
 
 	int ulAction = GetChoice(XRCID("ID_UPLOAD_ACTION"));
 	if (ulAction < 0 || ulAction >= CFileExistsNotification::ACTION_COUNT)
 		ulAction = 0;
-	m_pOptions->SetOption(OPTION_FILEEXISTS_UPLOAD, ulAction);
+	m_pOptions->set(OPTION_FILEEXISTS_UPLOAD, ulAction);
 
-	m_pOptions->SetOption(OPTION_ASCIIRESUME, GetCheck(XRCID("ID_ASCIIRESUME")));
+	m_pOptions->set(OPTION_ASCIIRESUME, GetCheck(XRCID("ID_ASCIIRESUME")));
 	return true;
 }
 
