@@ -1,12 +1,14 @@
-#ifndef __SETTINGSDIALOG_H__
-#define __SETTINGSDIALOG_H__
+#ifndef FILEZILLA_INTERFACE_SETTINGS_SETTINGSDIALOG_HEADER
+#define FILEZILLA_INTERFACE_SETTINGS_SETTINGSDIALOG_HEADER
 
 #include "../dialogex.h"
 
-class COptions;
+#include "../Options.h"
+
 class COptionsPage;
 class CMainFrame;
-class CSettingsDialog : public wxDialogEx
+class wxTreeCtrlEx;
+class CSettingsDialog final : public wxDialogEx
 {
 public:
 	CSettingsDialog(CFileZillaEngineContext & engine_context);
@@ -19,14 +21,20 @@ public:
 
 	CFileZillaEngineContext& GetEngineContext() { return m_engine_context; }
 
+	void RememberOldValue(interfaceOptions option);
+
 protected:
 	bool LoadPages();
 
 	COptions* m_pOptions;
 
+	wxPanel* pagePanel_{};
+
 	COptionsPage* m_activePanel{};
 
-	void AddPage( wxString const& name, COptionsPage* page, int nest );
+	wxTreeCtrlEx* tree_{};
+
+	void AddPage(wxString const& name, COptionsPage* page, int nest);
 
 	struct t_page
 	{
@@ -35,6 +43,8 @@ protected:
 	};
 	std::vector<t_page> m_pages;
 
+	std::map<interfaceOptions, std::wstring> m_oldValues;
+
 	DECLARE_EVENT_TABLE()
 	void OnPageChanging(wxTreeEvent& event);
 	void OnPageChanged(wxTreeEvent& event);
@@ -44,4 +54,4 @@ protected:
 	CFileZillaEngineContext& m_engine_context;
 };
 
-#endif //__SETTINGSDIALOG_H__
+#endif
