@@ -1,9 +1,12 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "sitemanager_controls.h"
 
 #include "dialogex.h"
 #include "fzputtygen_interface.h"
 #include "Options.h"
+#if USE_MAC_SANDBOX
+#include "osx_sandbox_userdirs.h"
+#endif
 #include "sitemanager.h"
 #if ENABLE_STORJ
 #include "storj_key_interface.h"
@@ -12,7 +15,7 @@
 #include "xrc_helper.h"
 #include "wxext/spinctrlex.h"
 
-#include <s3sse.h>
+#include "../include/s3sse.h"
 
 #include <libfilezilla/translate.hpp>
 
@@ -608,13 +611,13 @@ bool GeneralSiteControls::UpdateSite(Site & site, bool silent)
 		logon_type = supportedlogonTypes.front();
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 0 &&
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 0 &&
 			!predefined_ &&
 	        (logon_type == LogonType::account || logon_type == LogonType::normal))
 	{
 		if (!silent) {
 			wxString msg;
-			if (COptions::Get()->OptionFromFzDefaultsXml(OPTION_DEFAULT_KIOSKMODE) && COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 0) {
+			if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 0 && COptions::Get()->predefined(OPTION_DEFAULT_KIOSKMODE)) {
 				msg = _("Saving of password has been disabled by your system administrator.");
 			}
 			else {
