@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "sitemanager_dialog.h"
 
 #include "asksavepassworddialog.h"
@@ -23,6 +23,7 @@
 #include <wx/filedlg.h>
 #include <wx/menu.h>
 #include <wx/statline.h>
+#include <wx/wupdlock.h>
 
 #include <algorithm>
 #include <array>
@@ -585,7 +586,7 @@ public:
 		}
 		m_lastSelectionIt = m_lastSelection.cbegin();
 
-		m_kiosk = COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE);
+		m_kiosk = COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE);
 	}
 
 	virtual ~CSiteManagerXmlHandler_Tree()
@@ -756,7 +757,7 @@ bool CSiteManagerDialog::Load()
 		return true;
 	}
 
-	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED);
+	std::wstring lastSelection = COptions::Get()->get_string(OPTION_SITEMANAGER_LASTSELECTED);
 	if (!lastSelection.empty() && lastSelection[0] == '0') {
 		if (lastSelection == _T("0")) {
 			tree_->SafeSelectItem(treeId);
@@ -818,7 +819,7 @@ bool CSiteManagerDialog::Save(pugi::xml_node element, wxTreeItemId treeId)
 		bool res = Save(element, m_ownSites);
 
 		if (!xml.Save(false)) {
-			if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2) {
+			if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) == 2) {
 				return res;
 			}
 			wxString msg = wxString::Format(_("Could not write \"%s\", any changes to the Site Manager could not be saved: %s"), xml.GetFileName(), xml.GetError());
@@ -1114,7 +1115,7 @@ void CSiteManagerDialog::OnDelete(wxCommandEvent&)
 
 void CSiteManagerDialog::OnSelChanging(wxTreeEvent& event)
 {
-	if (m_is_deleting) {
+	if (m_is_deleting || tree_->ShouldIgnoreChangeEvent()) {
 		return;
 	}
 
@@ -1143,7 +1144,7 @@ void CSiteManagerDialog::OnSelChanging(wxTreeEvent& event)
 
 void CSiteManagerDialog::OnSelChanged(wxTreeEvent& evt)
 {
-	if (m_is_deleting) {
+	if (m_is_deleting || tree_->ShouldIgnoreChangeEvent()) {
 		return;
 	}
 
@@ -1153,6 +1154,7 @@ void CSiteManagerDialog::OnSelChanged(wxTreeEvent& evt)
 		m_is_deleting = false;
 	}
 
+	wxWindowUpdateLocker l(this);
 	SetCtrlState();
 }
 
@@ -1410,22 +1412,34 @@ void CSiteManagerDialog::OnSearch(wxCommandEvent&)
 
 	wxString search = dlg.GetValue().Lower();
 
-	m_is_deleting = true;
-	tree_->UnselectAll();
-
 	bool match{};
-	wxTreeItemId item = tree_->GetRootItem();
-	while (item) {
-		auto name = tree_->GetItemText(item).Lower();
-		if (name.find(search) != wxString::npos) {
-			tree_->SafeSelectItem(item, false);
-			match = true;
-		}
 
-		item = tree_->GetNextItemSimple(item, true);
+	{
+		wxWindowUpdateLocker l(this);
+
+		m_is_deleting = true;
+		tree_->UnselectAll();
+
+		wxTreeItemId item = tree_->GetRootItem();
+		while (item) {
+			bool select{};
+			if (item != tree_->GetRootItem() && item != m_ownSites && item != m_predefinedSites) {
+				auto name = tree_->GetItemText(item).Lower();
+				if (name.find(search) != wxString::npos) {
+					select = true;
+				}
+			}
+
+			if (select) {
+				tree_->SafeSelectItem(item, false);
+				match = true;
+			}
+
+			item = tree_->GetNextItemSimple(item, true);
+		}
+		SetCtrlState();
+		m_is_deleting = false;
 	}
-	SetCtrlState();
-	m_is_deleting = false;
 
 	if (match) {
 		tree_->SetFocus();
@@ -1523,7 +1537,7 @@ bool CSiteManagerDialog::LoadDefaultSites()
 	tree_->SetItemImage(m_predefinedSites, 1, wxTreeItemIcon_Expanded);
 	tree_->SetItemImage(m_predefinedSites, 1, wxTreeItemIcon_SelectedExpanded);
 
-	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED);
+	std::wstring lastSelection = COptions::Get()->get_string(OPTION_SITEMANAGER_LASTSELECTED);
 	if (!lastSelection.empty() && lastSelection[0] == '1') {
 		if (lastSelection == _T("1")) {
 			tree_->SafeSelectItem(m_predefinedSites);
@@ -1567,7 +1581,7 @@ void CSiteManagerDialog::OnBeginDrag(wxTreeEvent& event)
 	}
 #endif
 
-	if (COptions::Get()->GetOptionVal(OPTION_DND_DISABLED) != 0) {
+	if (COptions::Get()->get_int(OPTION_DND_DISABLED) != 0) {
 		event.Veto();
 		return;
 	}
@@ -1889,7 +1903,7 @@ void CSiteManagerDialog::RememberLastSelected()
 		path = GetSitePath(sel);
 	}
 	
-	COptions::Get()->SetOption(OPTION_SITEMANAGER_LASTSELECTED, path);
+	COptions::Get()->set(OPTION_SITEMANAGER_LASTSELECTED, path);
 }
 
 void CSiteManagerDialog::OnContextMenu(wxTreeEvent&)
