@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 
 #if FZ_MANUALUPDATECHECK
 
@@ -14,6 +14,7 @@
 #include <libfilezilla/process.hpp>
 
 #include <wx/animate.h>
+#include <wx/display.h>
 #include <wx/hyperlink.h>
 #include <wx/statline.h>
 
@@ -237,7 +238,16 @@ void MakeLinksFromTooltips(wxWindow& parent)
 void CUpdateDialog::InitFooter()
 {
 #if FZ_WINDOWS
-	if (CBuildInfo::GetBuildType() == _T("official") && !COptions::Get()->GetOptionVal(OPTION_DISABLE_UPDATE_FOOTER)) {
+	int d = wxDisplay::GetFromWindow(this);
+	if (d != wxNOT_FOUND) {
+		wxDisplay display(d);
+		wxRect r = display.GetGeometry();
+		if (r.GetHeight() < 960) {
+			return;
+		}
+	}
+
+	if (CBuildInfo::GetBuildType() == _T("official") && !COptions::Get()->get_int(OPTION_DISABLE_UPDATE_FOOTER)) {
 		wxString const resources = updater_.GetResources();
 		if (!resources.empty()) {
 			wxLogNull null;
@@ -273,6 +283,8 @@ void CUpdateDialog::Wrap()
 		return;
 	}
 
+	GetSizer()->Fit(this);
+
 	wxSize canvas;
 	canvas.x = GetSize().x - content_->GetSize().x;
 	canvas.y = GetSize().y - content_->GetSize().y;
@@ -374,7 +386,7 @@ void CUpdateDialog::UpdaterStateChanged(UpdaterState s, build const& v)
 		bool const outdated = s == UpdaterState::newversion_stale;
 		bool const manual = s == UpdaterState::newversion || outdated;
 		bool const dlfail = s == UpdaterState::newversion && !v.url_.empty();
-		bool const disabled = COptions::Get()->GetOptionVal(OPTION_DEFAULT_DISABLEUPDATECHECK) != 0 || !COptions::Get()->GetOptionVal(OPTION_UPDATECHECK);
+		bool const disabled = COptions::Get()->get_int(OPTION_DEFAULT_DISABLEUPDATECHECK) != 0 || !COptions::Get()->get_int(OPTION_UPDATECHECK);
 
 		XRCCTRL(*this, "ID_OUTDATED", wxStaticText)->Show(outdated);
 		XRCCTRL(*this, "ID_DISABLED_CHECK", wxStaticText)->Show(outdated && disabled);
@@ -400,7 +412,7 @@ void CUpdateDialog::OnInstall(wxCommandEvent&)
 	if (f.empty()) {
 		return;
 	}
-	COptions::Get()->SetOption(OPTION_GREETINGRESOURCES, updater_.GetResources());
+	COptions::Get()->set(OPTION_GREETINGRESOURCES, updater_.GetResources());
 #ifdef __WXMSW__
 	std::vector<std::wstring> cmd_with_args;
 	cmd_with_args.push_back(f);
