@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "filezillaapp.h"
 #include "verifycertdialog.h"
 #include "dialogex.h"
@@ -10,6 +10,7 @@
 
 #include <libfilezilla/iputils.hpp>
 
+#include <wx/display.h>
 #include <wx/gbsizer.h>
 #include <wx/scrolwin.h>
 #include <wx/statbox.h>
@@ -237,7 +238,7 @@ void CertStore::SetInsecure(std::string const& host, unsigned int port, bool per
 		return;
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 2) {
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 2) {
 		auto root = m_xmlFile.GetElement();
 		if (root) {
 			auto certs = root.child("TrustedCerts");
@@ -310,7 +311,7 @@ void CertStore::SetTrusted(fz::tls_session_info const& info, bool permanent, boo
 		return;
 	}
 
-	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 2) {
+	if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 2) {
 		auto root = m_xmlFile.GetElement();
 		if (root) {
 			auto certs = root.child("TrustedCerts");
@@ -428,9 +429,21 @@ bool CVerifyCertDialog::DisplayCert(fz::x509_certificate const& cert)
 	impl_->signature_algo_->SetLabel(fz::to_wstring_from_utf8(cert.get_signature_algorithm()));
 
 	auto recalc = [this](wxWindow* panel, wxSizer* sizer) {
+
 		sizer->Fit(panel);
 		wxSize min = sizer->CalcMin();
-		int const maxHeight = (line_height_ + layout().dlgUnits(1)) * 20;
+		int maxHeight = (line_height_ + layout().dlgUnits(1)) * 20;
+
+		int d = wxDisplay::GetFromWindow(this);
+		if (d != wxNOT_FOUND) {
+			wxDisplay display(d);
+			wxRect r = display.GetClientArea();
+			int h = r.GetHeight() - line_height_ * 25; // Assume rest of the dialog is about 25 lines
+			if (maxHeight > h) {
+				maxHeight = h;
+			}
+		}
+
 		if (min.y >= maxHeight) {
 			min.y = maxHeight;
 			min.x += wxSystemSettings::GetMetric(wxSYS_VSCROLL_X);
@@ -690,7 +703,7 @@ bool CVerifyCertDialog::CreateVerificationDialog(CCertificateNotification const&
 
 	if (!displayOnly) {
 		main->Add(new wxStaticText(this, -1, _("Trust the server certificate and carry on connecting?")));
-		if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) != 2) {
+		if (COptions::Get()->get_int(OPTION_DEFAULT_KIOSKMODE) != 2) {
 			impl_->always_ = new wxCheckBox(this, -1, _("&Always trust this certificate in future sessions."));
 			main->Add(impl_->always_);
 		}
